@@ -77,7 +77,10 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
             chrono::offset::Local::now().timestamp(),
         )?;
 
-        Command::new("ssh").arg(host_name).spawn()?.wait()?;
+        Command::new("ssh")
+            .arg(host_name.split(' ').take(1).collect::<Vec<&str>>().join(""))
+            .spawn()?
+            .wait()?;
     }
 
     Ok(())
